Index: sdk/lib/_internal/compiler/compiler.dart |
diff --git a/sdk/lib/_internal/compiler/compiler.dart b/sdk/lib/_internal/compiler/compiler.dart |
index bbee705a0386725a035cfbb0f97a335768543b70..3bac4f323b092b49b4fee66c2c4d509d71a760b5 100644 |
--- a/sdk/lib/_internal/compiler/compiler.dart |
+++ b/sdk/lib/_internal/compiler/compiler.dart |
@@ -22,7 +22,7 @@ typedef Future<String> CompilerInputProvider(Uri uri); |
typedef Future<String> ReadStringFromUri(Uri uri); |
/** |
* Returns a [StreamSink] that will serve as compiler output for the given |
* component. |
* |
* Components are identified by [name] and [extension]. By convention, |
@@ -41,7 +41,7 @@ typedef Future<String> ReadStringFromUri(Uri uri); |
* As more features are added to the compiler, new names and |
* extensions may be introduced. |
*/ |
-typedef StreamSink<String> CompilerOutputProvider(String name, |
+typedef EventSink<String> CompilerOutputProvider(String name, |
String extension); |
floitsch
2013/03/07 14:19:34
@@ -22,7 +22,7 @@ typedef Future<String> CompilerInputProvider(Uri uri); |
typedef Future<String> ReadStringFromUri(Uri uri); |
/** |
- * Returns a [StreamSink] that will serve as compiler output for the given |
+ * Returns a [EventSink] that will serve as compiler output for the given |
* component. |
* |
indentation.
Lasse Reichstein Nielsen
2013/03/08 10:18:25
Done.
|
/** |